@@ -51,13 +51,16 @@ public:
     \param tag [i] タグ
     \param file [i] データファイル名
   */
-  void setRestrictedData(const std::string& tag, const std::string& file);
+  void setRestrictData(const std::string& tag, const std::string& file);
 
 
   /*!
     \brief リリースファイルの作成
+
+    \retval true 正常
+    \retval false エラー
   */
-  void release(void);
+  bool release(void);
 };
 
 #endif /* !RRDA_DECODER_H */
