@@ -17,6 +17,7 @@
 #include "ArchiveConfig.h"
 #include "SettingConfig.h"
 #include "ReleaseDialog.h"
+#include "ReleaseDataFile.h"
 
 
 namespace {
@@ -94,7 +95,7 @@ struct ThemeConfigWindow::pImpl {
   pImpl(void)
     : new_act_(NULL), open_act_(NULL), save_act_(NULL),
       archive_config_(NULL), setting_config_(NULL), save_ok_(false),
-      same_hands_center_(true), scene_(NULL) {
+      same_hands_center_(false), scene_(NULL) {
   }
 
 
@@ -121,6 +122,7 @@ struct ThemeConfigWindow::pImpl {
             parent, SLOT(analogCheckHandler(bool)));
     connect(parent->digital_checkbox_, SIGNAL(clicked(bool)),
             parent, SLOT(digitalCheckHandler(bool)));
+    same_hands_center_ = parent->center_checkbox_->isChecked();
 
     // メニューイベントの接続
     connect(parent->action_exit_, SIGNAL(triggered()), parent, SLOT(close()));
@@ -134,6 +136,12 @@ struct ThemeConfigWindow::pImpl {
     (void) new QShortcut(Qt::Key_Down, parent, SLOT(downPressed()));
 
     // 部品画像の更新
+    connect(parent->image_lineedit_, SIGNAL(returnPressed()),
+            parent, SLOT(partsEditHandler()));
+    connect(parent->update_button_, SIGNAL(clicked()),
+            parent, SLOT(updateHandlelr()));
+
+    // 部品表示ツリー
     connect(parent->parts_tree_, SIGNAL(itemSelectionChanged()),
             parent, SLOT(imageUploadHandler()));
 
@@ -245,6 +253,7 @@ struct ThemeConfigWindow::pImpl {
 
     // 再生ボタン
     parent->play_button_->setEnabled(enable);
+    parent->offset_slidebar_->setEnabled(enable);
 
     // 編集用 Widget
     parent->groupbox_->setEnabled(enable);
@@ -414,14 +423,14 @@ struct ThemeConfigWindow::pImpl {
     parent = registerItem(parent, "base/base_org");
 
     // デジタル部品
-    registerItem(parent, "digital/h1", "1");
-    registerItem(parent, "digital/h2", "2");
-    registerItem(parent, "digital/m1", "3");
-    registerItem(parent, "digital/m2", "4");
+    registerItem(parent, "digital/h1", "0");
+    registerItem(parent, "digital/h2", "1");
+    registerItem(parent, "digital/m1", "2");
+    registerItem(parent, "digital/m2", "3");
 
     if (! strcmp("on", setting_config_->getValue("digital/sec"))) {
-      registerItem(parent, "digital/s1", "5");
-      registerItem(parent, "digital/s2", "6");
+      registerItem(parent, "digital/s1", "4");
+      registerItem(parent, "digital/s2", "5");
     }
 
     registerItem(parent, "digital/cl", ":");
@@ -627,6 +636,19 @@ struct ThemeConfigWindow::pImpl {
       return;
     }
 
+    // アナログ部品をまとめて操作させる
+    if (! tag.compare("analog")) {
+      bool pre_flag = same_hands_center_;
+      same_hands_center_ = false;
+
+      updatePosition(parent, x, y, "analog/hari_h");
+      updatePosition(parent, x, y, "analog/hari_m");
+      updatePosition(parent, x, y, "analog/hari_s");
+
+      same_hands_center_ = pre_flag;
+      return;
+    }
+
     // "digital/parts" タグのときは、"digital/XX" を全て移動させる
     if (! tag.compare("digital/parts")) {
       updatePosition(parent, x, y, "digital/h1");
@@ -667,6 +689,24 @@ struct ThemeConfigWindow::pImpl {
 
     setSaveEnabled(parent, true);
   }
+
+
+  // リリースファイルの作成
+  void release(void) {
+
+    releaseDataFile(*archive_config_);
+  }
+
+
+  // 登録していある名前を変更し、画像を更新する
+  void updateItemName(const QString& fileName) {
+
+    const char* archive_tag = setting_config_->getValue(current_tag_.c_str());
+    archive_config_->setNormalData(archive_tag, fileName.toStdString().c_str());
+
+    loadImage(current_tag_.c_str());
+    updateItems();
+  }
 };
 
 
@@ -715,6 +755,7 @@ ThemeConfigWindow::ThemeConfigWindow(const QString& config_file)
   // ファイルが指定されていれば、読み出し
   if (! config_file.isEmpty()) {
     pimpl->loadArchiveFile(this, config_file.toStdString().c_str());
+    pimpl->setSaveEnabled(this, false);
   }
 
   // アナログ画像のサブツリーを開く
@@ -795,7 +836,9 @@ void ThemeConfigWindow::saveFileAs(void) {
 void ThemeConfigWindow::releaseData(void) {
 
   // リリース名、キー値の設定
-  pimpl->release_dialog_.setDefaultValue("name", "key");
+  const char* name = pimpl->archive_config_->getReleaseName();
+  const char* key = pimpl->archive_config_->getRrdaKey();
+  pimpl->release_dialog_.setDefaultValue(name, key);
 
   // ダイアログの表示
   pimpl->release_dialog_.show();
@@ -807,9 +850,11 @@ void ThemeConfigWindow::releaseData(void) {
 void ThemeConfigWindow::releaseHandler(const QString& file,
                                        const QString& key) {
 
-  fprintf(stderr, "%s, %s\n",
-          file.toStdString().c_str(), key.toStdString().c_str());
-  // !!!
+  // 登録情報の更新
+  pimpl->archive_config_->setReleaseName(file.toStdString().c_str());
+  pimpl->archive_config_->setRrdaKey(key.toStdString().c_str());
+
+  pimpl->release();
 }
 
 
@@ -888,18 +933,21 @@ void ThemeConfigWindow::imageUploadHandler(void) {
     // タグが見つからなければ戻る
     return;
   }
+  std::string tag = p.value();
 
   // カーソルのイベントハンドラが、現在のタグに従って処理を行う
-  pimpl->current_tag_ = p.value();
+  pimpl->current_tag_ = tag;
 
   size_t n = sizeof(ImageTags) / sizeof(ImageTags[0]);
   bool found = pimpl->findItemTag(ImageTags, n, pimpl->current_tag_);
   if (! found) {
     // 画像の以外ならば、アップロードフォームを無効化
+    image_lineedit_->setText("");
     pimpl->setUpdateEnabled(this, false);
 
   } else {
     // 画像のアップロードフォームを有効化
+    image_lineedit_->setText(pimpl->name_to_item_[tag]->text(1));
     pimpl->setUpdateEnabled(this, true);
   }
 }
@@ -930,7 +978,26 @@ void ThemeConfigWindow::downPressed(void) {
 
 
 
-// 部品画像の更新
+// 部品画像の更新、文字列入力
+void ThemeConfigWindow::partsEditHandler(void) {
+
+  pimpl->updateItemName(image_lineedit_->text());
+}
+
+
+// 部品画像の更新、選択
+void ThemeConfigWindow::updateHandlelr(void) {
+
+  QString fileName =
+    QFileDialog::getOpenFileName(this, tr("Open parts file."), ".",
+                                 tr("parts file (*.png)"));
+
+  if (! fileName.isEmpty()) {
+    pimpl->updateItemName(fileName.toStdString().c_str());
+  }
+}
+
+
 // !!! slot
 // !!! ドラッグ & ドロップで画像ファイルを選択できるようにする
 // !!! 画像でなければ、実際には登録しない
