@@ -47,6 +47,9 @@ private slots:
   void upPressed(void);
   void downPressed(void);
 
+  void partsEditHandler(void);
+  void updateHandlelr(void);
+
   void releaseHandler(const QString& file, const QString& key);
 
 public:
